Struct HealthOsc1Cr
#[repr(transparent)]pub struct HealthOsc1Cr(pub u32);Expand description
HEALTH_OSC1_CR register.
Tuple Fields
0: u32Implementations
impl HealthOsc1Cr
impl HealthOsc1Cr
pub const fn repet_cutoff_osc1(&self) -> u8
pub const fn repet_cutoff_osc1(&self) -> u8
Cutoff value of Repetition Test. The default value is set to 51. Caution: To be handled with care as any change can lead to misbehavior of TRNG.
pub fn set_repet_cutoff_osc1(&mut self, val: u8)
pub fn set_repet_cutoff_osc1(&mut self, val: u8)
Cutoff value of Repetition Test. The default value is set to 51. Caution: To be handled with care as any change can lead to misbehavior of TRNG.
pub const fn adap_cutoff_osc1(&self) -> u16
pub const fn adap_cutoff_osc1(&self) -> u16
Cutoff value of Adaptive Test. The default value is set to 699. Caution: To be handled with care as any change can lead to misbehavior of TRNG.
pub fn set_adap_cutoff_osc1(&mut self, val: u16)
pub fn set_adap_cutoff_osc1(&mut self, val: u16)
Cutoff value of Adaptive Test. The default value is set to 699. Caution: To be handled with care as any change can lead to misbehavior of TRNG.