Struct HealthOsc2Sr
#[repr(transparent)]pub struct HealthOsc2Sr(pub u32);Expand description
HEALTH_OSC2_SR register.
Tuple Fields
0: u32Implementations
impl HealthOsc2Sr
impl HealthOsc2Sr
pub const fn to1_repet_error(&self) -> bool
pub const fn to1_repet_error(&self) -> bool
Repetition error flag of first oscillator of first triple-oscillator cell.
pub fn set_to1_repet_error(&mut self, val: bool)
pub fn set_to1_repet_error(&mut self, val: bool)
Repetition error flag of first oscillator of first triple-oscillator cell.
pub const fn to1_adapt_error(&self) -> bool
pub const fn to1_adapt_error(&self) -> bool
Adaptive error flag of first oscillator of first triple-oscillator cell.
pub fn set_to1_adapt_error(&mut self, val: bool)
pub fn set_to1_adapt_error(&mut self, val: bool)
Adaptive error flag of first oscillator of first triple-oscillator cell.
pub const fn to2_repet_error(&self) -> bool
pub const fn to2_repet_error(&self) -> bool
Repetition error flag of first oscillator of second triple-oscillator cell.
pub fn set_to2_repet_error(&mut self, val: bool)
pub fn set_to2_repet_error(&mut self, val: bool)
Repetition error flag of first oscillator of second triple-oscillator cell.
pub const fn to2_adapt_error(&self) -> bool
pub const fn to2_adapt_error(&self) -> bool
Adaptive error flag of first oscillator of second triple-oscillator cell.
pub fn set_to2_adapt_error(&mut self, val: bool)
pub fn set_to2_adapt_error(&mut self, val: bool)
Adaptive error flag of first oscillator of second triple-oscillator cell.
pub const fn to3_repet_error(&self) -> bool
pub const fn to3_repet_error(&self) -> bool
Repetition error flag of first oscillator of third triple-oscillator cell.
pub fn set_to3_repet_error(&mut self, val: bool)
pub fn set_to3_repet_error(&mut self, val: bool)
Repetition error flag of first oscillator of third triple-oscillator cell.
pub const fn to3_adapt_error(&self) -> bool
pub const fn to3_adapt_error(&self) -> bool
Adaptive error flag of first oscillator of third triple-oscillator cell.
pub fn set_to3_adapt_error(&mut self, val: bool)
pub fn set_to3_adapt_error(&mut self, val: bool)
Adaptive error flag of first oscillator of third triple-oscillator cell.