Struct IrqCr
#[repr(transparent)]pub struct IrqCr(pub u32);Expand description
IRQ_CR register.
Tuple Fields
0: u32Implementations
impl IrqCr
impl IrqCr
pub const fn en_ff_full_irq(&self) -> bool
pub const fn en_ff_full_irq(&self) -> bool
Enable the interrupt when the output fifo is full of new random.
pub fn set_en_ff_full_irq(&mut self, val: bool)
pub fn set_en_ff_full_irq(&mut self, val: bool)
Enable the interrupt when the output fifo is full of new random.
pub const fn en_error_irq(&self) -> bool
pub const fn en_error_irq(&self) -> bool
Enable the interrupt when an error is reported by the health tests.
pub fn set_en_error_irq(&mut self, val: bool)
pub fn set_en_error_irq(&mut self, val: bool)
Enable the interrupt when an error is reported by the health tests.