Struct IrqSr
#[repr(transparent)]pub struct IrqSr(pub u32);Expand description
IRQ_SR register.
Tuple Fields
0: u32Implementations
impl IrqSr
impl IrqSr
pub const fn ff_full_irq(&self) -> bool
pub const fn ff_full_irq(&self) -> bool
Set to 1 when the output fifo is full of new random. Flag is cleared by writing a 1.
pub fn set_ff_full_irq(&mut self, val: bool)
pub fn set_ff_full_irq(&mut self, val: bool)
Set to 1 when the output fifo is full of new random. Flag is cleared by writing a 1.
pub const fn error_irq(&self) -> bool
pub const fn error_irq(&self) -> bool
Set to 1 when an error is reported by the health tests. Flag is cleared by writing a 1.
pub fn set_error_irq(&mut self, val: bool)
pub fn set_error_irq(&mut self, val: bool)
Set to 1 when an error is reported by the health tests. Flag is cleared by writing a 1.