stm32-metapac

Crates

git

Versions

stm32wb09ke

Flavors

PostpCr

Struct PostpCr 

#[repr(transparent)]
pub struct PostpCr(pub u32);
POSTP_CR register.

Tuple Fields

0: u32

Implementations



impl PostpCr

pub const fn aes_reset(&self) -> AesReset

Reset AES post processing. When writing a 1, the AES post processing is reinitialized, resulting in a new key and new state generation before 128-bit random words generation. The ‘1’ written is frozen until it is seen by RNG core clock domain after resynchronization. Then it is automatically reset. It also reruns analog source health tests.

pub fn set_aes_reset(&mut self, val: AesReset)

Reset AES post processing. When writing a 1, the AES post processing is reinitialized, resulting in a new key and new state generation before 128-bit random words generation. The ‘1’ written is frozen until it is seen by RNG core clock domain after resynchronization. Then it is automatically reset. It also reruns analog source health tests.

pub const fn nb_loop_aes(&self) -> u8

NB_LOOP_AES is the number of 128-bit words got from the noise source that have to be processed by AES for generating a single 128-bit random word. By default, this value is set to 2 (128 bits generated before an AES processing). 0 value means 16 loops. A new AES processing is started only when the previous one is completed.

pub fn set_nb_loop_aes(&mut self, val: u8)

NB_LOOP_AES is the number of 128-bit words got from the noise source that have to be processed by AES for generating a single 128-bit random word. By default, this value is set to 2 (128 bits generated before an AES processing). 0 value means 16 loops. A new AES processing is started only when the previous one is completed.

pub const fn nb_rnd_reinit(&self) -> u16

Number of 128-bit random words generated before AES automatically resets. This number is in the range of 1 to 65535 words. Value 0x0000 means that AES is never reinitialized.

pub fn set_nb_rnd_reinit(&mut self, val: u16)

Number of 128-bit random words generated before AES automatically resets. This number is in the range of 1 to 65535 words. Value 0x0000 means that AES is never reinitialized.