Struct Sr
#[repr(transparent)]pub struct Sr(pub u32);Expand description
SR register.
Tuple Fields
0: u32Implementations
impl Sr
impl Sr
pub fn set_disabled(&mut self, val: bool)
pub fn set_disabled(&mut self, val: bool)
TRNG is disabled.
pub const fn all_oscs_down(&self) -> AllOscsDown
pub const fn all_oscs_down(&self) -> AllOscsDown
All oscillators of the random source noise have been powered down. This can cause the rising of OEC3 flag.
pub fn set_all_oscs_down(&mut self, val: AllOscsDown)
pub fn set_all_oscs_down(&mut self, val: AllOscsDown)
All oscillators of the random source noise have been powered down. This can cause the rising of OEC3 flag.
pub const fn reveal_clk_err(&self) -> RevealClkErr
pub const fn reveal_clk_err(&self) -> RevealClkErr
The internal clock for the RNG core is not revealed.
pub fn set_reveal_clk_err(&mut self, val: RevealClkErr)
pub fn set_reveal_clk_err(&mut self, val: RevealClkErr)
The internal clock for the RNG core is not revealed.
pub const fn entropy_err(&self) -> EntropyErr
pub const fn entropy_err(&self) -> EntropyErr
The error refers to a fault in the bit sequence detected by the Entropy Monitor. Failed test is given by REPET_ERROR, and ADAPT_ERROR, OSCS_REPET_ERROR and OSCS_ADAPT_ERROR status flags.
pub fn set_entropy_err(&mut self, val: EntropyErr)
pub fn set_entropy_err(&mut self, val: EntropyErr)
The error refers to a fault in the bit sequence detected by the Entropy Monitor. Failed test is given by REPET_ERROR, and ADAPT_ERROR, OSCS_REPET_ERROR and OSCS_ADAPT_ERROR status flags.
pub const fn val_ready(&self) -> ValReady
pub const fn val_ready(&self) -> ValReady
TRNG Value ready At least one 32-bit random value is available in the data FIFO. Note that application must ensure that a random is available in internal FIFO before starting a read otherwise a bus error will be generated.
pub fn set_val_ready(&mut self, val: ValReady)
pub fn set_val_ready(&mut self, val: ValReady)
TRNG Value ready At least one 32-bit random value is available in the data FIFO. Note that application must ensure that a random is available in internal FIFO before starting a read otherwise a bus error will be generated.
pub fn set_fifo_full(&mut self, val: FifoFull)
pub fn set_fifo_full(&mut self, val: FifoFull)
Indicates whether random data FIFO is full.
pub const fn src_health_done(&self) -> bool
pub const fn src_health_done(&self) -> bool
First run of noise source health test is completed.
pub fn set_src_health_done(&mut self, val: bool)
pub fn set_src_health_done(&mut self, val: bool)
First run of noise source health test is completed.
pub const fn repet_error(&self) -> bool
pub const fn repet_error(&self) -> bool
Noise source Repetition health test error.
pub fn set_repet_error(&mut self, val: bool)
pub fn set_repet_error(&mut self, val: bool)
Noise source Repetition health test error.
pub const fn adapt_error(&self) -> bool
pub const fn adapt_error(&self) -> bool
Noise source Adaptive 1024 health test error.
pub fn set_adapt_error(&mut self, val: bool)
pub fn set_adapt_error(&mut self, val: bool)
Noise source Adaptive 1024 health test error.
pub const fn oscs_health_done(&self) -> bool
pub const fn oscs_health_done(&self) -> bool
First run of source health tests of individual oscillators composing the noise source are completed.Reserved.
pub fn set_oscs_health_done(&mut self, val: bool)
pub fn set_oscs_health_done(&mut self, val: bool)
First run of source health tests of individual oscillators composing the noise source are completed.Reserved.
pub const fn oscs_repet_error(&self) -> bool
pub const fn oscs_repet_error(&self) -> bool
Logical OR of repetition health test errors of individual oscillators composing the noise source.
pub fn set_oscs_repet_error(&mut self, val: bool)
pub fn set_oscs_repet_error(&mut self, val: bool)
Logical OR of repetition health test errors of individual oscillators composing the noise source.
pub const fn oscs_adapt_error(&self) -> bool
pub const fn oscs_adapt_error(&self) -> bool
Logical OR of adaptive health test errors of individual oscillators composing the noise source.
pub fn set_oscs_adapt_error(&mut self, val: bool)
pub fn set_oscs_adapt_error(&mut self, val: bool)
Logical OR of adaptive health test errors of individual oscillators composing the noise source.