Struct Val
#[repr(transparent)]pub struct Val(pub u32);Expand description
VAL register.
Tuple Fields
0: u32Implementations
impl Val
impl Val
pub const fn rnd_val(&self) -> u32
pub const fn rnd_val(&self) -> u32
RND_VAL is a 32-bit Random Value. This is the output of the internal four-word FIFO. Note that application must ensure that a random is available in FIFO by ready VAL_READY flag before starting a read otherwise a null value will be returned.
pub fn set_rnd_val(&mut self, val: u32)
pub fn set_rnd_val(&mut self, val: u32)
RND_VAL is a 32-bit Random Value. This is the output of the internal four-word FIFO. Note that application must ensure that a random is available in FIFO by ready VAL_READY flag before starting a read otherwise a null value will be returned.