Struct PostpSr
#[repr(transparent)]pub struct PostpSr(pub u32);Expand description
POSTP_SR register.
Tuple Fields
0: u32Implementations
impl PostpSr
impl PostpSr
pub const fn aes_init(&self) -> AesInit
pub const fn aes_init(&self) -> AesInit
AES Post processing has been fully initialized (key and state) and is ready for generating 128-bit random words.
pub fn set_aes_init(&mut self, val: AesInit)
pub fn set_aes_init(&mut self, val: AesInit)
AES Post processing has been fully initialized (key and state) and is ready for generating 128-bit random words.
pub const fn aes_key_ld(&self) -> AesKeyLd
pub const fn aes_key_ld(&self) -> AesKeyLd
AES random key has been generated and loaded in AES key register.
pub fn set_aes_key_ld(&mut self, val: AesKeyLd)
pub fn set_aes_key_ld(&mut self, val: AesKeyLd)
AES random key has been generated and loaded in AES key register.
pub fn set_aes_busy(&mut self, val: AesBusy)
pub fn set_aes_busy(&mut self, val: AesBusy)
AES core is busy, generating a random value.
pub const fn aes_health_done(&self) -> bool
pub const fn aes_health_done(&self) -> bool
AES-CMAC health test is completed.
pub fn set_aes_health_done(&mut self, val: bool)
pub fn set_aes_health_done(&mut self, val: bool)
AES-CMAC health test is completed.
pub const fn aes_k12_error(&self) -> bool
pub const fn aes_k12_error(&self) -> bool
Health test error on AES-CMAC sub-keys generation.
pub fn set_aes_k12_error(&mut self, val: bool)
pub fn set_aes_k12_error(&mut self, val: bool)
Health test error on AES-CMAC sub-keys generation.
pub const fn aes_dout_error(&self) -> bool
pub const fn aes_dout_error(&self) -> bool
Health test error on AES-CMAC output generation.
pub fn set_aes_dout_error(&mut self, val: bool)
pub fn set_aes_dout_error(&mut self, val: bool)
Health test error on AES-CMAC output generation.